pub struct Newton<F> { /* private fields */ }Expand description
Newton’s method
Newton’s method iteratively finds the stationary points of a function f by using a second order approximation of f at the current point.
The stepsize gamma can be adjusted with the with_gamma method. It
must be in (0, 1]) and defaults to 1.
Requirements on the optimization problem
The optimization problem is required to implement Gradient and Hessian.
Reference
Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization. Springer. ISBN 0-387-30303-0.
Implementations