pub struct NewtonCG<L, F> { /* private fields */ }Expand description
Newton-Conjugate-Gradient (Newton-CG) method
The Newton-CG method (also called truncated Newton method) uses a modified CG to approximately solve the Newton equations. After a search direction is found, a line search is performed.
Requirements on the optimization problem
The optimization problem is required to implement Gradient and Hessian.
Reference
Jorge Nocedal and Stephen J. Wright (2006). Numerical Optimization. Springer. ISBN 0-387-30303-0.
Implementations
Sourceimpl<L, F> NewtonCG<L, F>where
F: ArgminFloat,
impl<L, F> NewtonCG<L, F>where
F: ArgminFloat,
Sourcepub fn with_curvature_threshold(self, threshold: F) -> Self
pub fn with_curvature_threshold(self, threshold: F) -> Self
Set curvature threshold
Defaults to 0.
Example
let ncg: NewtonCG<_, f64> = NewtonCG::new(linesearch).with_curvature_threshold(1e-6);Sourcepub fn with_tolerance(self, tol: F) -> Result<Self, Error>
pub fn with_tolerance(self, tol: F) -> Result<Self, Error>
Set tolerance for the stopping criterion based on cost difference
Must be larger than 0 and defaults to EPSILON.
Example
let ncg: NewtonCG<_, f64> = NewtonCG::new(linesearch).with_tolerance(1e-6)?;Trait Implementations
Sourceimpl<'de, L, F> Deserialize<'de> for NewtonCG<L, F>where
L: Deserialize<'de>,
F: Deserialize<'de>,
impl<'de, L, F> Deserialize<'de> for NewtonCG<L, F>where
L: Deserialize<'de>,
F: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<O, L, P, G, H, F> Solver<O, IterState<P, G, (), H, (), F>> for NewtonCG<L, F>where
O: Gradient<Param = P, Gradient = G> + Hessian<Param = P, Hessian = H>,
P: Clone + ArgminSub<P, P> + ArgminDot<P, F> + ArgminScaledAdd<P, F, P> + ArgminMul<F, P> + ArgminConj + ArgminZeroLike,
G: ArgminL2Norm<F> + ArgminMul<F, P>,
H: Clone + ArgminDot<P, P>,
L: Clone + LineSearch<P, F> + Solver<O, IterState<P, G, (), (), (), F>>,
F: ArgminFloat + ArgminL2Norm<F>,
impl<O, L, P, G, H, F> Solver<O, IterState<P, G, (), H, (), F>> for NewtonCG<L, F>where
O: Gradient<Param = P, Gradient = G> + Hessian<Param = P, Hessian = H>,
P: Clone + ArgminSub<P, P> + ArgminDot<P, F> + ArgminScaledAdd<P, F, P> + ArgminMul<F, P> + ArgminConj + ArgminZeroLike,
G: ArgminL2Norm<F> + ArgminMul<F, P>,
H: Clone + ArgminDot<P, P>,
L: Clone + LineSearch<P, F> + Solver<O, IterState<P, G, (), (), (), F>>,
F: ArgminFloat + ArgminL2Norm<F>,
Sourcefn next_iter(
&mut self,
problem: &mut Problem<O>,
state: IterState<P, G, (), H, (), F>,
) -> Result<(IterState<P, G, (), H, (), F>, Option<KV>), Error>
fn next_iter( &mut self, problem: &mut Problem<O>, state: IterState<P, G, (), H, (), F>, ) -> Result<(IterState<P, G, (), H, (), F>, Option<KV>), Error>
Computes a single iteration of the algorithm and has access to the optimization problem
definition and the internal state of the solver.
Returns an updated
state and optionally a KV which holds key-value pairs used in
Observers.Sourcefn terminate(
&mut self,
state: &IterState<P, G, (), H, (), F>,
) -> TerminationStatus
fn terminate( &mut self, state: &IterState<P, G, (), H, (), F>, ) -> TerminationStatus
Used to implement stopping criteria, in particular criteria which are not covered by
(
terminate_internal. Read moreSourcefn init(
&mut self,
_problem: &mut Problem<O>,
state: I,
) -> Result<(I, Option<KV>), Error>
fn init( &mut self, _problem: &mut Problem<O>, state: I, ) -> Result<(I, Option<KV>), Error>
Initializes the algorithm. Read more
Sourcefn terminate_internal(&mut self, state: &I) -> TerminationStatus
fn terminate_internal(&mut self, state: &I) -> TerminationStatus
Checks whether basic termination reasons apply. Read more